@@ -1,6 +1,3 @@
-#ifndef lint
-static const char SCCSID[]="@(#)PJ_gall.c	4.1	94/02/15	GIE	REL";
-#endif
 #define PJ_LIB__
 #include	<projects.h>
 PROJ_HEAD(gall, "Gall (Gall Stereographic)") "\n\tCyl, Sph";
@@ -9,11 +6,13 @@ PROJ_HEAD(gall, "Gall (Gall Stereographic)") "\n\tCyl, Sph";
 #define RYF	0.58578643762690495119
 #define RXF	1.41421356237309504880
 FORWARD(s_forward); /* spheroid */
+	(void) P;
 	xy.x = XF * lp.lam;
 	xy.y = YF * tan(.5 * lp.phi);
 	return (xy);
 }
 INVERSE(s_inverse); /* spheroid */
+	(void) P;
 	lp.lam = RXF * xy.x;
 	lp.phi = 2. * atan(xy.y * RYF);
 	return (lp);
